==> anyscale-0.5.170.tar.gz: anyscale-0.5.170/anyscale/commands/fine_tune_commands.py <==
from typing import Optional

import click

from anyscale.controllers.fine_tune_controller import FineTuneController
from anyscale.models.fine_tune_model import FineTuneConfig


@click.group(
    "fine-tuning", help="Interact with fine-tuning jobs running on Anyscale.",
)
def fine_tune_cli() -> None:
    pass


@fine_tune_cli.command(name="submit")
@click.argument("base-model", required=True)
@click.option("--train-file", required=True, help="The path of the training file.")
@click.option(
    "--valid-file",
    required=False,
    default=None,
    help="The path of the validation file.",
)
@click.option("--cloud-id", required=True, help="The id of the cloud")
@click.option(
    "--suffix",
    required=False,
    default=None,
    help="The suffix of the fine-tuned model.",
)
@click.option(
    "--version",
    required=False,
    default=None,
    help=(
        "The version of Aviary expected to be used for the fine-tuned model. "
        "If not specified, the latest version will be used."
    ),
)
def submit(
    base_model: str,
    train_file: str,
    valid_file: Optional[str],
    cloud_id: str,
    suffix: Optional[str],
    version: Optional[str],
) -> None:
    """
    Submits a fine-tuning job.

    Example usage:

        anyscale fine-tuning submit --model meta-llama/Llama-2-7b-chat-hf --train-file train.jsonl --cloud-id CLOUD_ID
    """
    fine_tune_controller = FineTuneController()
    config = FineTuneConfig(
        base_model=base_model,
        train_file=train_file,
        valid_file=valid_file,
        cloud_id=cloud_id,
        suffix=suffix,
        version=version,
    )
    fine_tune_controller.fine_tune(config=config)

==> anyscale-0.5.172.tar.gz: anyscale-0.5.172/anyscale/commands/fine_tune_commands.py <==
from typing import Optional

import click

from anyscale.controllers.fine_tune_controller import FineTuneController
from anyscale.models.fine_tune_model import FineTuneConfig


@click.group(
    "fine-tuning", help="Interact with fine-tuning jobs running on Anyscale.",
)
def fine_tune_cli() -> None:
    pass


@fine_tune_cli.command(name="submit")
@click.argument("base-model", required=True)
@click.option("--train-file", required=True, help="The path of the training file.")
@click.option(
    "--valid-file",
    required=False,
    default=None,
    help="The path of the validation file.",
)
@click.option("--cloud-id", required=True, help="The id of the cloud")
@click.option(
    "--suffix",
    required=False,
    default=None,
    help="The suffix of the fine-tuned model.",
)
@click.option(
    "--version",
    required=False,
    default=None,
    help=(
        "The version of ray-llm expected to be used for the fine-tuned model. "
        "If not specified, the latest version will be used."
    ),
)
def submit(
    base_model: str,
    train_file: str,
    valid_file: Optional[str],
    cloud_id: str,
    suffix: Optional[str],
    version: Optional[str],
) -> None:
    """
    Submits a fine-tuning job.

    Example usage:

        anyscale fine-tuning submit --model meta-llama/Llama-2-7b-chat-hf --train-file train.jsonl --cloud-id CLOUD_ID
    """
    fine_tune_controller = FineTuneController()
    config = FineTuneConfig(
        base_model=base_model,
        train_file=train_file,
        valid_file=valid_file,
        cloud_id=cloud_id,
        suffix=suffix,
        version=version,
    )
    fine_tune_controller.fine_tune(config=config)
